<!--
This document describes how each VM OS image is created and the post-install steps that have been undertaken.
-->

# Common to all distribs

- username: `nexus`
- password: `nexus`
- if root, password: `nexus`
- hostname: `nexus-pc`
- login without password if selectable (autologin)

 TODO:

- flatpak:
  ```
  sudo flatpak remote-add flathub https://flathub.org/repo/flathub.flatpakrepo
  flatpak install io.atom.Atom
  ```
- VSCode:
  ```
  sudo snap install code --classic
  ctrl+p: ext install ms-vscode.cpptools
  ctrl+p: ext install ms-vscode.cpptools-extension-pack
  ```
- Keyboard tweaks:
  - rate: 250ms
  - char/sec: 40
- Extra packages?
  ```
  git geany clang libsdl2-dev neovim valgrind python3-matplotlib python3-numpy openjdk-18-jdk screen tmux uuid-runtime gnutls-bin
  ```

# Ubuntu/Xubuntu

Images: `ubuntu-22.04-desktop-amd64.iso` and `xubuntu-22.04-desktop-amd64.iso`

```
sudo -s
apt-get update && apt-get upgrade -y
apt-get install -y qemu-guest-agent vim tree qalc build-essential net-tools
snap install codium --classic
apt-get remove --purge -y thunderbird
apt autoremove && apt autoclean
fstrim -av
systemctl enable fstrim.timer && sudo systemctl start fstrim.timer
```

# Fedora

Image: `Fedora-Workstation-Live-x86_64-36-1.5.iso`

```
sudo -s
dnf update && sudo dnf upgrade
dnf install vim tree qalc snapd
ln -s /var/lib/snapd/snap /snap
snap install codium --classic
fstrim -av
systemctl enable fstrim.timer && systemctl start fstrim.timer
```

# Debian

Image: `debian-11.4.0-amd64-DVD-1.iso` with xfce desktop.

Skip the grub menu, otherwise it takes forever: change `/etc/default/grub` with:
```
GRUB_TIMEOUT=0
```

Update grub with:
```
update-grub && update-grub2
```

Setup autologin by adding the following to `/etc/lightdm/lightdm.conf` under `[Seat:*]`:
```
autologin-user=nexus
autologin-user-timeout=0
```

Add sources by adding the following to `/etc/apt/sources.list`:
```
deb http://deb.debian.org/debian bullseye main contrib non-free
deb-src http://deb.debian.org/debian bullseye main contrib non-free
deb http://deb.debian.org/debian-security bullseye/updates main contrib non-free
deb-src http://deb.debian.org/debian-security bullseye/updates main contrib non-free
deb http://deb.debian.org/debian bullseye-updates main contrib non-free
deb-src http://deb.debian.org/debian bullseye-updates main contrib non-free
deb http://deb.debian.org/debian bullseye-backports main contrib non-free
deb-src http://deb.debian.org/debian bullseye-backports main contrib non-free
```

```
su -
apt-get update && apt-get upgrade -y
apt-get install -y qemu-guest-agent vim tree qalc build-essential net-tools snapd
snap install core
systemctl restart snapd && systemctl enable snapd
snap install codium --classic
apt autoremove && apt autoclean
fstrim -av
systemctl enable fstrim.timer && systemctl start fstrim.timer
```

# Manjaro

Image: `manjaro-xfce-21.3.6-220729-linux515.iso`

```
sudo -s
pamac update && pamac --no-confirm upgrade
pamac install --no-confirm code vim tree qalculate-gtk net-tools
fstrim -av
systemctl enable fstrim.timer && systemctl start fstrim.timer
```

# Xfce

Disable display of windows full content when moving + resizing to reduce network bandwidth:

- Settings Manager -> Window Manager Tweaks -> Compositor -> uncheck "Enable display compositing"
- Settings Manager -> Window Manager -> Style -> Daloa
- Settings Manager -> Window Manager -> Advanced -> Hide content of windows -> check "When moving" and "When resizing"

